"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isDisabled = exports["default"] = exports.completeButtons = exports.FormControls = void 0;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _useFormApi2 = _interopRequireDefault(require("@data-driven-forms/react-form-renderer/use-form-api"));

var _formSpy = _interopRequireDefault(require("@data-driven-forms/react-form-renderer/form-spy"));

var _excluded = ["FormWrapper", "Title", "Description", "Button", "ButtonGroup", "formWrapperProps", "showFormControls", "disableSubmit", "Header", "headerProps", "titleProps", "descriptionProps", "buttonGroupProps", "buttonsProps", "alertProps", "BeforeError"];

var isDisabled = function isDisabled(disableStates, getState) {
  return disableStates.map(function (item) {
    return getState()[item];
  }).find(function (item) {
    return !!item;
  });
};

exports.isDisabled = isDisabled;

var completeButtons = function completeButtons(buttonOrder) {
  var expectedOrder = (0, _toConsumableArray2["default"])(buttonOrder);

  if (!expectedOrder.includes('submit')) {
    expectedOrder.push('submit');
  }

  if (!expectedOrder.includes('reset')) {
    expectedOrder.push('reset');
  }

  if (!expectedOrder.includes('cancel')) {
    expectedOrder.push('cancel');
  }

  return expectedOrder;
};

exports.completeButtons = completeButtons;

var FormControls = function FormControls(_ref) {
  var onCancel = _ref.onCancel,
      onReset = _ref.onReset,
      _ref$submitLabel = _ref.submitLabel,
      submitLabel = _ref$submitLabel === void 0 ? 'Submit' : _ref$submitLabel,
      _ref$cancelLabel = _ref.cancelLabel,
      cancelLabel = _ref$cancelLabel === void 0 ? 'Cancel' : _ref$cancelLabel,
      _ref$resetLabel = _ref.resetLabel,
      resetLabel = _ref$resetLabel === void 0 ? 'Reset' : _ref$resetLabel,
      _ref$canReset = _ref.canReset,
      canReset = _ref$canReset === void 0 ? false : _ref$canReset,
      disableSubmit = _ref.disableSubmit,
      _ref$buttonOrder = _ref.buttonOrder,
      buttonOrder = _ref$buttonOrder === void 0 ? ['submit', 'reset', 'cancel'] : _ref$buttonOrder,
      buttonClassName = _ref.buttonClassName,
      FormButtons = _ref.FormButtons,
      Button = _ref.Button,
      ButtonGroup = _ref.ButtonGroup,
      formSpyProps = _ref.formSpyProps,
      _ref$buttonsProps = _ref.buttonsProps,
      buttonsProps = _ref$buttonsProps === void 0 ? {} : _ref$buttonsProps,
      buttonGroupProps = _ref.buttonGroupProps;

  if (FormButtons) {
    return /*#__PURE__*/_react["default"].createElement(FormButtons, null);
  }

  var submitting = formSpyProps.submitting,
      pristine = formSpyProps.pristine,
      validating = formSpyProps.validating;
  var submit = buttonsProps.submit,
      reset = buttonsProps.reset,
      cancel = buttonsProps.cancel;
  var buttons = {
    submit: /*#__PURE__*/_react["default"].createElement(Button, (0, _extends2["default"])({
      key: "form-submit",
      type: "submit",
      variant: "primary",
      buttonType: "submit",
      disabled: submitting || validating || disableSubmit,
      label: submitLabel
    }, submit)),
    reset: canReset ? /*#__PURE__*/_react["default"].createElement(Button, (0, _extends2["default"])({
      key: "form-reset",
      type: "button",
      buttonType: "reset",
      disabled: pristine,
      onClick: onReset,
      label: resetLabel
    }, reset)) : null,
    cancel: onCancel ? /*#__PURE__*/_react["default"].createElement(Button, (0, _extends2["default"])({
      key: "form-cancel",
      type: "button",
      buttonType: "cancel",
      onClick: onCancel,
      label: cancelLabel
    }, cancel)) : null
  };
  return /*#__PURE__*/_react["default"].createElement(ButtonGroup, (0, _extends2["default"])({}, buttonGroupProps, buttonClassName && {
    className: buttonClassName
  }), completeButtons(buttonOrder).map(function (button) {
    return buttons[button];
  }));
};

exports.FormControls = FormControls;
FormControls.propTypes = {
  onCancel: _propTypes["default"].func,
  onReset: _propTypes["default"].func,
  submitLabel: _propTypes["default"].node,
  cancelLabel: _propTypes["default"].node,
  resetLabel: _propTypes["default"].node,
  canReset: _propTypes["default"].bool,
  disableSubmit: _propTypes["default"].bool,
  buttonOrder: _propTypes["default"].arrayOf(_propTypes["default"].string),
  buttonClassName: _propTypes["default"].string,
  FormButtons: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].element, _propTypes["default"].func]),
  Button: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].element, _propTypes["default"].func]),
  ButtonGroup: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].element, _propTypes["default"].func]),
  formSpyProps: _propTypes["default"].shape({
    submitting: _propTypes["default"].bool,
    pristine: _propTypes["default"].bool,
    validating: _propTypes["default"].bool,
    form: _propTypes["default"].shape({
      reset: _propTypes["default"].func
    }),
    values: _propTypes["default"].object
  }),
  buttonGroupProps: _propTypes["default"].object,
  buttonsProps: _propTypes["default"].object
};

var FormTemplate = function FormTemplate(_ref2) {
  var FormWrapper = _ref2.FormWrapper,
      Title = _ref2.Title,
      Description = _ref2.Description,
      Button = _ref2.Button,
      ButtonGroup = _ref2.ButtonGroup,
      formWrapperProps = _ref2.formWrapperProps,
      _ref2$showFormControl = _ref2.showFormControls,
      showFormControls = _ref2$showFormControl === void 0 ? true : _ref2$showFormControl,
      _ref2$disableSubmit = _ref2.disableSubmit,
      disableSubmit = _ref2$disableSubmit === void 0 ? [] : _ref2$disableSubmit,
      _ref2$Header = _ref2.Header,
      Header = _ref2$Header === void 0 ? _react["default"].Fragment : _ref2$Header,
      headerProps = _ref2.headerProps,
      titleProps = _ref2.titleProps,
      descriptionProps = _ref2.descriptionProps,
      buttonGroupProps = _ref2.buttonGroupProps,
      buttonsProps = _ref2.buttonsProps,
      alertProps = _ref2.alertProps,
      BeforeError = _ref2.BeforeError,
      rest = (0, _objectWithoutProperties2["default"])(_ref2, _excluded);
  var _rest$schema = rest.schema,
      title = _rest$schema.title,
      description = _rest$schema.description,
      label = _rest$schema.label,
      formFields = rest.formFields;

  var _useFormApi = (0, _useFormApi2["default"])(),
      onReset = _useFormApi.onReset,
      onCancel = _useFormApi.onCancel,
      getState = _useFormApi.getState,
      handleSubmit = _useFormApi.handleSubmit;

  return /*#__PURE__*/_react["default"].createElement(FormWrapper, (0, _extends2["default"])({
    onSubmit: handleSubmit
  }, formWrapperProps), (title || label || description) && /*#__PURE__*/_react["default"].createElement(Header, headerProps, (title || label) && /*#__PURE__*/_react["default"].createElement(Title, titleProps, title || label), description && /*#__PURE__*/_react["default"].createElement(Description, descriptionProps, description)), BeforeError && /*#__PURE__*/_react["default"].createElement(_formSpy["default"], {
    subscription: {
      submitError: true,
      error: true
    }
  }, function () {
    var state = getState();
    return /*#__PURE__*/_react["default"].createElement(BeforeError, {
      formError: state.error || state.submitError,
      formSpyProps: state,
      alertProps: alertProps
    });
  }), formFields, showFormControls && /*#__PURE__*/_react["default"].createElement(_formSpy["default"], null, function (formSpyProps) {
    return /*#__PURE__*/_react["default"].createElement(FormControls, (0, _extends2["default"])({
      Button: Button,
      FormSpy: _formSpy["default"],
      buttonGroupProps: buttonGroupProps,
      buttonsProps: buttonsProps,
      ButtonGroup: ButtonGroup,
      onReset: onReset,
      onCancel: onCancel,
      disableSubmit: isDisabled(disableSubmit, getState),
      formSpyProps: formSpyProps
    }, rest));
  }));
};

FormTemplate.propTypes = {
  FormWrapper: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element]).isRequired,
  Title: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element]).isRequired,
  Description: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element]).isRequired,
  Button: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element]).isRequired,
  ButtonGroup: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element]).isRequired,
  formWrapperProps: _propTypes["default"].object,
  showFormControls: _propTypes["default"].bool,
  disableSubmit: _propTypes["default"].arrayOf(_propTypes["default"].string),
  Header: _propTypes["default"].oneOfType([_propTypes["default"].node, _propTypes["default"].func, _propTypes["default"].element, _propTypes["default"].oneOf([_react["default"].Fragment])]),
  headerProps: _propTypes["default"].object,
  titleProps: _propTypes["default"].object,
  descriptionProps: _propTypes["default"].object,
  buttonGroupProps: _propTypes["default"].object,
  buttonsProps: _propTypes["default"].object,
  BeforeError: _propTypes["default"].elementType,
  alertProps: _propTypes["default"].object
};
var _default = FormTemplate;
exports["default"] = _default;